@@ -92,7 +92,7 @@ def _create_mode(ui, cfg):
 
     ui.check_output_file_exists(_utils.get_torrent_filepath(torrent, cfg))
     ui.show_torrent(torrent)
-    _hash_pieces(ui, torrent)
+    _hash_pieces(ui, torrent, threads=cfg['threads'])
     _write_torrent(ui, torrent, cfg)
     return torrent
 
@@ -194,11 +194,12 @@ def _verify_mode(ui, cfg):
                 raise _errors.VerifyError(content=cfg['PATH'], torrent=cfg['in'])
     return torrent
 
-def _hash_pieces(ui, torrent):
+def _hash_pieces(ui, torrent, threads=0):
     with ui.StatusReporter() as sr:
         try:
             success = torrent.generate(callback=sr.generate_callback,
-                                       interval=PROGRESS_INTERVAL)
+                                       interval=PROGRESS_INTERVAL,
+                                       threads=threads or None)
         except torf.TorfError as e:
             raise _errors.Error(e)
         except KeyboardInterrupt:
