@@ -108,10 +108,14 @@ class UI:
         if torrent.piece_size:
             info('Piece Count', torrent.pieces)
         info('File Count', len(torrent.files))
-        patterns = [p for p in torrent.exclude_globs]
-        patterns.extend(r.pattern for r in torrent.exclude_regexs)
-        if patterns:
-            info('Exclude', patterns)
+        exclude_patterns = [p for p in torrent.exclude_globs]
+        exclude_patterns.extend(r.pattern for r in torrent.exclude_regexs)
+        if exclude_patterns:
+            info('Exclude', exclude_patterns)
+        include_patterns = [p for p in torrent.include_globs]
+        include_patterns.extend(r.pattern for r in torrent.include_regexs)
+        if include_patterns:
+            info('Include', include_patterns)
         info('Files', self._fmt.files(torrent))
 
     def StatusReporter(self):
@@ -176,13 +180,13 @@ class _HumanFormatter(_FormatterBase):
 
     def trackers(self, torrent):
         lines = []
-        if all(len(tier) <= 1 for tier in torrent.trackers):
-            # One tracker per tier - don't bother with printing tiers
+        if len(torrent.trackers) == 1 and len(torrent.trackers[0]) == 1:
+            # Single tracker in single tier - don't bother displaying tiers
             for tier in torrent.trackers:
                 if tier:
                     lines.append(tier[0])
         else:
-            # At least one tier has multiple trackers
+            # Show which tier each tracker belongs to
             tier_label_width = len('Tier :') + len(str(len(torrent.trackers)))
             for i,tier in enumerate(torrent.trackers, 1):
                 if tier:
